@@ -1,7 +1,7 @@
-package CPAN::Reporter::FAQ;
+package CPAN::Reporter::FAQ
 # Not really a .pm file, but holds wikidoc which will be
 # turned into .pod by the Build.PL
-$VERSION = '0.99_14'; ## no critic
+$VERSION = "0.36";
 use strict; # make CPANTS happy
 1;
 __END__
@@ -18,27 +18,19 @@ This documentation refers to version %%VERSION%%
 
 = REPORT GRADES
 
-== Why did I receive a report?  The grade was PASS/FAIL/UNKNOWN/NA!
+== Why did I receive an NA report?  The test failed because of a missing prerequisite!
 
-If you received a report, it's because the person using CPAN::Reporter
-chose to copy you on the report in addition to sending it to CPAN Testers.  
-CPAN::Reporter suggests that only FAIL and UNKNOWN reports be copied to 
-authors, but individual users may override that default.
+An NA report indicates missing prerequisites (and may eventually
+indicate unsupported platforms).  As of version 0.36, CPAN::Reporter
+defaults to not sending NA reports.  Earlier versions will send NA
+reports if they occur or a user might have changed the defaults so
+as to send NA reports.
 
-== Why was a report sent if a prerequisite is missing?
-
-As of CPAN::Reporter 0.46, FAIL and UNKNOWN reports with unsatisfied 
-prerequisites are discarded.  Earlier versions may have sent these reports 
-out by mistake as either an NA or UNKNOWN report.
-
-PASS reports are not discarded because it may be useful to know when tests
-passed despite a missing prerequisite.  NA reports are sent because information
-about the lack of support for a platform is relevant regardless of
-prerequisites.
+Generally, module authors may simply choose to ignore NA reports.
 
 = SENDING REPORTS
 
-== Why did I get an error sending a test report?
+== Why did I get a error sending a test report?
 
 Test reports are sent via ordinary email.  The most common reason for errors
 sending a report is that many Internet Service Providers (ISP's) will block
@@ -70,22 +62,11 @@ time they appear on the CPAN Testers website. There is a further delay before
 summary statistics appear on search.cpan.org.
 
 If your email address is subscribed to the list but your test reports are still
-not showing up, your outbound email may have been silently blocked by your
+not showing up, your outbound email may have been silentely blocked by your
 ISP.  See the question above about errors sending reports.
 
-== Why don't you support sending reports via HTTP or authenticated SMTP?
-
-CPAN::Reporter uses [Test::Reporter] as its conduit to CPAN Testers.  
-As soon as Test::Reporter provides support for alternative transport 
-methods, support for them will be added to CPAN::Reporter.
-
 = CPAN TESTERS
 
-== Where can I find out more about CPAN Testers?
-
-A good place to start is the CPAN Testers Wiki: 
-[http://cpantest.grango.org/]
-
 == Where can I find statistics about reports sent to CPAN Testers?
 
 CPAN Testers statistics are compiled at [http://perl.grango.org/]
@@ -106,7 +87,6 @@ email address in the {email_from} option.
 
 = SEE ALSO
 
-* [CPAN::Testers]
 * [CPAN::Reporter]
 * [Test::Reporter]
 
@@ -114,25 +94,42 @@ email address in the {email_from} option.
 
 David A. Golden (DAGOLDEN)
 
+dagolden@cpan.org
+
+http://dagolden.com/
+
 = COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, 2007 by David A. Golden
+Copyright (c) 2006 by David A. Golden
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at 
-[http://www.apache.org/licenses/LICENSE-2.0]
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
-Files produced as output though the use of this software, including
-generated copies of boilerplate templates provided with this software,
-shall not be considered Derivative Works, but shall be considered the
-original work of the Licensor.
+The full text of the license can be found in the LICENSE file included with
+this module.
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+= DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =end wikidoc
 
